<?php
	/*
		Plugin Name:		Category Thumbnails
		Plugin URI:			http://hovida-design.de/plugin-kategorie-thumbnails/
		Author:				Adrian Preuss
		Version:			1.0.1
		Description:		This Plugin provide functions like post-thumbnails for categories. Please visit the Author-URL for Documentation.
	*/
	
	class Category_Thumbnails {
		// Global Variables
		protected static $name		= "category-thumbnails";
		protected static $active	= false;
		protected static $actions	= array(
			"init"							=> "init",
			"admin_init"					=> "admin_init",
			"edit_category_form_fields"		=> "edit",
			"category_add_form_fields"		=> "create",
			"edited_category"				=> "save",
			"created_category"				=> "save",
			"admin_print_scripts"			=> "admin_script",
			"admin_print_styles"			=> "admin_style"
		);
		
		// Initalization		
		function __construct() {
			load_plugin_textdomain(self::$name, false, dirname(plugin_basename(__FILE__)) . '/languages/');
			register_activation_hook(__FILE__,				array("Category_Thumbnails", "install"));
			register_deactivation_hook(__FILE__,			array("Category_Thumbnails", "uninstall"));

			foreach(self::$actions AS $hook => $method) {
				add_action($hook,							array("Category_Thumbnails", $method));
			}
			
			add_filter('manage_edit-category_columns',		array("Category_Thumbnails", "table_header"));  
			add_filter('manage_category_custom_column',		array("Category_Thumbnails", "table_body"), 10, 3);  
		}
		
		public static function admin_init() {
			global $pagenow;
			
			if('media-upload.php' == $pagenow || 'async-upload.php' == $pagenow) {  
				add_filter('gettext', array('Category_Thumbnails', 'thickbox_button'), 20, 3); 
			} 
		}
		
		public static function init() {
			if(current_theme_supports(self::$name)) {
				self::$active = true;
			} else {
				self::$active = false;
			}
		}
		
		// Scripts and Styles
		public static function admin_script() {
			if(function_exists('wp_enqueue_media')){
				wp_enqueue_media();
			} else {
				wp_enqueue_style('thickbox');
				wp_enqueue_script('media-upload');
				wp_enqueue_script('thickbox');
			}
		}

		public static function admin_style() {
			wp_enqueue_style('thickbox');
		}
		
		public static function getScript() {
			print '<script type="text/javascript" src="' . plugin_dir_url(__FILE__) . 'base64.js"></script>';
			print '<script type="text/javascript" src="' . plugin_dir_url(__FILE__) . 'media-upload.js"></script>';
			
			if(isset($_POST['action']) && $_POST['action'] == "add-tag") {
				print '<script type="text/javascript">category_thumbnail_clear();</script>';
			}
		}
		
		function thickbox_button($translated_text, $text, $domain) {
			if('Insert into Post' == $text) {
				if(isset($_GET['referer']) && preg_match('/' . self::$name . '/', $_GET['referer'])) { 
					return __('Insert into Category', self::$name);  
				}  
			}  
		
			return $translated_text;  
		}  
		
		// Get UI
		public static function getUI($category = null) {
			$exists	= (isset($category->term_thumbnail) && $category->term_thumbnail != "none" && $category->term_thumbnail != "" && $category->term_thumbnail != "NULL" ? true : false);
			
			if(isset($_POST['action']) && $_POST['action'] == "add-tag") {
				$exists = false;
			}
			
			return $hook . '<div id="create-thumbnail"' . ($exists ? " style=\"display: none;\"" : "") . '>
						<p class="submit">
							<input type="button" name="submit" style="width: auto;" id="set-category-thumbnail" class="button button-primary" value="' . __("add Category image", self::$name) . '" />
						</p>
					</div>
					<div id="preview-thumbnail" style="display: ' . ($exists ? "block" : "none") . ';">
						<a title="' . __("edit Thumbnail", self::$name) . '" href="#" id="reset-category-thumbnail">
							<img src="' . $exists . '" alt="" />
						</a>
						<p class="submit">
							<input type="button" name="submit" style="width: auto;" id="let-category-thumbnail" class="button button-primary" value="' . __("remove Category image", self::$name) . '" />
						</p>
					</div>
					<input type="hidden" name="category-thumbnail" id="category-thumbnail" value="' . ($exists ? base64_encode($category->term_thumbnail) : "none") . '" />
					<p>' . sprintf(__("This Category image will be displayed if the Theme supports %s.", self::$name), "<strong>" . self::$name . "</strong>") . '</p>';
		}

		public static function table_header($old_columns) {
			$i								= 0;
			$columns						= array();
			$columns[key($old_columns)]		= $old_columns[reset($old_columns)];
			$columns[self::$name]			= '<a href="edit-tags.php?taxonomy=category&orderby=name&order=asc"><span>Thumbnail</span><span class="sorting-indicator"></span></a>';
			
			foreach($old_columns AS $name => $value) {
				if($i > 0) {
					$columns[$name] = $value;
				}
				$i++;
			}
			
			return $columns;
		}
		
		public static function table_body($deprecated, $column_name, $term_id) {
			global $wpdb;
			
			if($column_name == self::$name) {
				if(has_category_thumbnail($term_id)) {
					the_category_thumbnail($term_id, array(50, 50));
				}
			}
		}
		
		// Create Category
		public static function create($category) {
			if(self::$active) {
				self::getScript();
				print '<div class="form-field">
						<label for="tag-thumb">' . __("Thumbnail", self::$name) . '</label>
						' . self::getUI() . '
					</div>';
			}
		}
		
		// Edit Category
		public static function edit($category) {
			if(self::$active) {
				self::getScript();
				print '<tr class="form-field">
							<th scope="row" valign="top"><label for="parent">' . __("Thumbnail", self::$name) . '</label></th>
							<td>
								' . self::getUI($category) . '
							</td>
						</tr>';
			}
		}
		
		// Save Category
		public static function save($category) {
			global $wpdb;
			$data = isset($_POST['category-thumbnail']) ? $_POST['category-thumbnail'] : "none";
			
			if($data == "none" || $data == "" || $data == "NULL") {
				$data = NULL;		
			}
			
			$wpdb->query("UPDATE `" . $wpdb->prefix . "term_taxonomy` SET `term_thumbnail`=" . ($data == NULL ? "NULL" : "'" . base64_decode($data) . "'") . " WHERE `term_id`='" . $category . "' LIMIT 1");
		}
		
		// Installation
		public static function install() {
			global $wpdb;
			
			$wpdb->query("ALTER TABLE `" . $wpdb->prefix . "term_taxonomy` ADD `term_thumbnail` TEXT AFTER `count`");
		}
		
		public static function uninstall() {
			global $wpdb;
			
			$wpdb->query("ALTER TABLE `" . $wpdb->prefix . "term_taxonomy` DROP `term_thumbnail`");
		}
	}
	
	// Global WP-Functions
	function has_category_thumbnail($category_id = null) {
		global $cat;
		global $wpdb;
		
		if($category_id != null) {
			$cat = $category_id;	
		}
		
		$result = $wpdb->get_row("SELECT `term_thumbnail` FROM `" . $wpdb->prefix . "term_taxonomy` WHERE `term_id`='" . $cat . "' LIMIT 1");
		return $result->term_thumbnail != null ? true : false;
	}
	
	function the_category_thumbnail($category_id = null, $sizes = array()) {		
		print get_the_category_thumbnail($cat, $sizes);
	}
	
	function get_the_category_thumbnail($category_id = null, $sizes = array()) {
		global $cat;
		global $wpdb;
		
		if($category_id != null) {
			$cat = $category_id;	
		}
		
		$size			= "";
		$attributes		= "";
		$result			= $wpdb->get_row("SELECT `term_thumbnail` FROM `" . $wpdb->prefix . "term_taxonomy` WHERE `term_id`='" . $cat . "' LIMIT 1");
		$data			= json_decode($result->term_thumbnail);
		
		if(count($sizes) == 2) {
			$size = 'width="' . $sizes[0] . '" height="' . $sizes[1] . '" ';
		}
		
		if($size != "") {
			$attributes .= $size;
		}
		
		if(!empty($data->alt)) {
			$attributes .= ' alt="' . $data->alt . '" ';
		} else {
			$attributes .= ' alt="" ';
		}
		
		if(!empty($data->title)) {
			$attributes .= ' title="' . $data->title . '" ';
		}
		
		return sprintf('<img src="%s"%s />', $data->url, $attributes);
	}
	
	// Call
	new Category_Thumbnails();
?>